import { FindOptions, PhysicalStore, PartialResult, FilterType, WithOptionalId, CreateResult } from '@furystack/core';
import { Constructable } from '@furystack/inject';
import { MongoClient, Collection } from 'mongodb';
/**
 * TypeORM Store implementation for FuryStack
 */
export declare class MongodbStore<T, TPrimaryKey extends keyof T> implements PhysicalStore<T, TPrimaryKey> {
    private readonly options;
    readonly primaryKey: TPrimaryKey;
    readonly model: Constructable<T>;
    private initLock;
    private collection?;
    private createIdFilter;
    private stringifyResultId;
    private parseFilter;
    getCollection(): Promise<Collection<T>>;
    constructor(options: {
        model: Constructable<T>;
        primaryKey: TPrimaryKey;
        db: string;
        collection: string;
        mongoClient: () => Promise<MongoClient>;
    });
    add(...entries: Array<WithOptionalId<T, TPrimaryKey>>): Promise<CreateResult<T>>;
    update(id: T[TPrimaryKey], data: Partial<T>): Promise<void>;
    count(filter?: FilterType<T>): Promise<number>;
    find<TFields extends Array<keyof T>>(filter: FindOptions<T, TFields>): Promise<Array<PartialResult<T, TFields>>>;
    private getProjection;
    get(key: T[TPrimaryKey], select?: Array<keyof T>): Promise<T | undefined>;
    remove(...keys: Array<T[TPrimaryKey]>): Promise<void>;
    dispose(): Promise<void>;
}
//# sourceMappingURL=mongodb-store.d.ts.map